pecos.qeclib.steane.gates\_sq.hadamards
=======================================

.. automodule:: pecos.qeclib.steane.gates_sq.hadamards











   .. rubric:: Classes

   .. autosummary::

      H
